/*  ----------------------------------------------------------------<Prolog>-
    Name:       sflfind.h
    Title:      Fast string searching functions
    Package:    Standard Function Library (SFL)

    Written:    1996/04/24  iMatix SFL project team <sfl@imatix.com>
    Revised:    1998/04/15  iMatix SFL project team <sfl@imatix.com>

    Synopsis:   Searches for a pattern within a string or block of memory
                using a variant of the Boyer-Moore algorithm (improved by
                Horspool and Sunday). As fast or faster than the normal
                Boyer-Moore algorithm for most search strings, and much
                simpler.  Includes basic functions for searching blocks of
                memory with known sizes, plus envelopes that search
                null-delimited strings.  Provides the option of repeatedly
                searching for the same pattern without re-parsing the pattern
                each time.  strfind_r() and memfind_r(), are reentrant
                versions of strfind() and memfind() for single searches, and
                strfind_rb() and memfind_rb() are reentrant versions of
                strfind() and memfind() supporting repeat searches against
                the same pattern.  Use of strfind() and memfind() is 
                discouraged (they are provided only for backwards 
                compatibility).

    Copyright:  Copyright (c) 1991-1998 iMatix
    License:    This is free software; you can redistribute it and/or modify
                it under the terms of the SFL License Agreement as provided
                in the file LICENSE.TXT.  This software is distributed in
                the hope that it will be useful, but without any warranty.
 ------------------------------------------------------------------</Prolog>-*/

#ifndef _SFLFIND_INCLUDED               /*  Allow multiple inclusions        */
#define _SFLFIND_INCLUDED

/*  Function prototypes                                                      */

#ifdef __cplusplus
extern "C" {
#endif

char *strfind    (const char *string, const char *pattern, Bool repeat_find);
char *strfind_r  (const char *string, const char *pattern);
char *strfind_rb (const char *string, const char *pattern, 
                  size_t *shift, Bool *repeat_find);

void *memfind    (const void *block, const size_t block_size,
                  const void *pattern, const size_t pattern_size, 
                  Bool repeat_find);
void *memfind_r  (const void *block, const size_t block_size,
                  const void *pattern, const size_t pattern_size);
void *memfind_rb (const void *in_block, const size_t block_size,
                  const void *in_pattern, const size_t pattern_size, 
                  size_t *shift, Bool *repeat_find);

char *txtfind    (const char *string,  const char *pattern);

#ifdef __cplusplus
}
#endif

#endif

